==> haskell-vault-0.3.1.5-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-IyBAW2Ljg0WKhEAvtn2LmP
key:                  vault-0.3.1.5-IyBAW2Ljg0WKhEAvtn2LmP
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  dd74b677b346b268dc3a5e88679573e8
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-IyBAW2Ljg0WKhEAvtn2LmP
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-85lkkmOSRZHDIzkr9EkKNp
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.5-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-13501RAmESa6IWjZvLzddK
key:                  vault-0.3.1.5-13501RAmESa6IWjZvLzddK
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  040e8048bec4c440fac61625e7274d45
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-13501RAmESa6IWjZvLzddK
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-D3m6G7BPJON5VQ2FLdROoK
    unordered-containers-0.2.20-3371VA61Be1CojVrkG24uM

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
